==> vtk-7.1.1-4-armv7h.pkg.tar.xz: vtk/vtkInteractorStyleTreeMapHover.java <==
// java wrapper for vtkInteractorStyleTreeMapHover object
//

package vtk;
import vtk.*;

public class vtkInteractorStyleTreeMapHover extends vtkInteractorStyleImage
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetLayout_2(vtkTreeMapLayout id0);
  public void SetLayout(vtkTreeMapLayout id0)
    { SetLayout_2(id0); }

  private native long GetLayout_3();
  public vtkTreeMapLayout GetLayout() {
    long temp = GetLayout_3();

    if (temp == 0) return null;
    return (vtkTreeMapLayout)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetTreeMapToPolyData_4(vtkTreeMapToPolyData id0);
  public void SetTreeMapToPolyData(vtkTreeMapToPolyData id0)
    { SetTreeMapToPolyData_4(id0); }

  private native long GetTreeMapToPolyData_5();
  public vtkTreeMapToPolyData GetTreeMapToPolyData() {
    long temp = GetTreeMapToPolyData_5();

    if (temp == 0) return null;
    return (vtkTreeMapToPolyData)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetLabelField_6(String id0);
  public void SetLabelField(String id0)
    { SetLabelField_6(id0); }

  private native String GetLabelField_7();
  public String GetLabelField()
    { return GetLabelField_7(); }

  private native void OnMouseMove_8();
  public void OnMouseMove()
    { OnMouseMove_8(); }

  private native void OnLeftButtonUp_9();
  public void OnLeftButtonUp()
    { OnLeftButtonUp_9(); }

  private native void HighLightItem_10(int id0);
  public void HighLightItem(int id0)
    { HighLightItem_10(id0); }

  private native void HighLightCurrentSelectedItem_11();
  public void HighLightCurrentSelectedItem()
    { HighLightCurrentSelectedItem_11(); }

  private native void SetInteractor_12(vtkRenderWindowInteractor id0);
  public void SetInteractor(vtkRenderWindowInteractor id0)
    { SetInteractor_12(id0); }

  private native void SetHighLightColor_13(double id0,double id1,double id2);
  public void SetHighLightColor(double id0,double id1,double id2)
    { SetHighLightColor_13(id0,id1,id2); }

  private native void SetSelectionLightColor_14(double id0,double id1,double id2);
  public void SetSelectionLightColor(double id0,double id1,double id2)
    { SetSelectionLightColor_14(id0,id1,id2); }

  private native void SetHighLightWidth_15(double id0);
  public void SetHighLightWidth(double id0)
    { SetHighLightWidth_15(id0); }

  private native double GetHighLightWidth_16();
  public double GetHighLightWidth()
    { return GetHighLightWidth_16(); }

  private native void SetSelectionWidth_17(double id0);
  public void SetSelectionWidth(double id0)
    { SetSelectionWidth_17(id0); }

  private native double GetSelectionWidth_18();
  public double GetSelectionWidth()
    { return GetSelectionWidth_18(); }

  public vtkInteractorStyleTreeMapHover() { super(); }

  public vtkInteractorStyleTreeMapHover(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.2.0-9-armv7h.pkg.tar.xz: vtk/vtkInteractorStyleTreeMapHover.java <==
// java wrapper for vtkInteractorStyleTreeMapHover object
//

package vtk;
import vtk.*;

public class vtkInteractorStyleTreeMapHover extends vtkInteractorStyleImage
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetLayout_2(vtkTreeMapLayout id0);
  public void SetLayout(vtkTreeMapLayout id0)
    { SetLayout_2(id0); }

  private native long GetLayout_3();
  public vtkTreeMapLayout GetLayout() {
    long temp = GetLayout_3();

    if (temp == 0) return null;
    return (vtkTreeMapLayout)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetTreeMapToPolyData_4(vtkTreeMapToPolyData id0);
  public void SetTreeMapToPolyData(vtkTreeMapToPolyData id0)
    { SetTreeMapToPolyData_4(id0); }

  private native long GetTreeMapToPolyData_5();
  public vtkTreeMapToPolyData GetTreeMapToPolyData() {
    long temp = GetTreeMapToPolyData_5();

    if (temp == 0) return null;
    return (vtkTreeMapToPolyData)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetLabelField_6(String id0);
  public void SetLabelField(String id0)
    { SetLabelField_6(id0); }

  private native String GetLabelField_7();
  public String GetLabelField()
    { return GetLabelField_7(); }

  private native void OnMouseMove_8();
  public void OnMouseMove()
    { OnMouseMove_8(); }

  private native void OnLeftButtonUp_9();
  public void OnLeftButtonUp()
    { OnLeftButtonUp_9(); }

  private native void HighLightItem_10(int id0);
  public void HighLightItem(int id0)
    { HighLightItem_10(id0); }

  private native void HighLightCurrentSelectedItem_11();
  public void HighLightCurrentSelectedItem()
    { HighLightCurrentSelectedItem_11(); }

  private native void SetInteractor_12(vtkRenderWindowInteractor id0);
  public void SetInteractor(vtkRenderWindowInteractor id0)
    { SetInteractor_12(id0); }

  private native void SetHighLightColor_13(double id0,double id1,double id2);
  public void SetHighLightColor(double id0,double id1,double id2)
    { SetHighLightColor_13(id0,id1,id2); }

  private native void SetSelectionLightColor_14(double id0,double id1,double id2);
  public void SetSelectionLightColor(double id0,double id1,double id2)
    { SetSelectionLightColor_14(id0,id1,id2); }

  private native void SetHighLightWidth_15(double id0);
  public void SetHighLightWidth(double id0)
    { SetHighLightWidth_15(id0); }

  private native double GetHighLightWidth_16();
  public double GetHighLightWidth()
    { return GetHighLightWidth_16(); }

  private native void SetSelectionWidth_17(double id0);
  public void SetSelectionWidth(double id0)
    { SetSelectionWidth_17(id0); }

  private native double GetSelectionWidth_18();
  public double GetSelectionWidth()
    { return GetSelectionWidth_18(); }

  public vtkInteractorStyleTreeMapHover() { super(); }

  public vtkInteractorStyleTreeMapHover(long id) { super(id); }
  public native long   VTKInit();

}
